@@ -18,8 +18,9 @@ func (e *IllTypedError) Error() string {
 	return fmt.Sprintf("IllTypedError: errors in package: %v", e.Pkg.Errors)
 }
 
-func BuildIssuesFromIllTypedError(errs []error, lintCtx *linter.Context) ([]result.Issue, error) {
-	var issues []result.Issue
+func BuildIssuesFromIllTypedError(errs []error, lintCtx *linter.Context) ([]*result.Issue, error) {
+	var issues []*result.Issue
+
 	uniqReportedIssues := map[string]bool{}
 
 	var other error
@@ -39,11 +40,19 @@ func BuildIssuesFromIllTypedError(errs []error, lintCtx *linter.Context) ([]resu
 				if uniqReportedIssues[err.Msg] {
 					continue
 				}
+
 				uniqReportedIssues[err.Msg] = true
 				lintCtx.Log.Errorf("typechecking error: %s", err.Msg)
 			} else {
+				key := fmt.Sprintf("%s.%d.%d.%s", issue.FilePath(), issue.Line(), issue.Column(), issue.Text)
+				if uniqReportedIssues[key] {
+					continue
+				}
+
+				uniqReportedIssues[key] = true
+
 				issue.Pkg = ill.Pkg // to save to cache later
-				issues = append(issues, *issue)
+				issues = append(issues, issue)
 			}
 		}
 	}
