@@ -1,4 +1,3 @@
-//golangcitest:args -Egci
 //golangcitest:config_path testdata/gci.yml
 //golangcitest:expected_exitcode 0
 package gci
@@ -7,7 +6,7 @@ import (
 	"fmt"
 
 	gcicfg "github.com/daixiang0/gci/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
 
 	"golang.org/x/tools/go/analysis"
 )
